/* gui.c
 *
 * Copyright (C) 2003 by Jason Day
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "config.h"

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <sys/types.h>
#include <unistd.h>

#include "gui.h"
#include "pprefs.h"
#include "plucker.h"
#include "libplugin.h"


static const char RCSID[] = "$Id: gui.c,v 1.6 2003/06/05 02:13:41 jday Exp $";


/* Global variables */
static GtkWidget *distiller_cmd_entry;
static GtkWidget *terminal_cmd_entry;
static GtkWidget *terminal_label;
static GtkWidget *install_dir_entry;

/* Local static functions */
static void cb_toggle_button (GtkWidget *widget, gpointer data);
static void cb_save (GtkWidget *widget, gpointer data);
static void cb_run_distiller (GtkWidget *widget, gpointer data);
static void cb_use_term (GtkWidget *widget, gpointer data);


int init_gui (GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id) {
    GtkWidget *vbox1;
    GtkWidget *button;
    GtkWidget *temp_hbox;
    GtkWidget *label;
    long ivalue;
    const char *svalue;

    jp_logf(JP_LOG_DEBUG, "Plucker: plugin gui started\n");

    vbox1 = gtk_vbox_new (FALSE, 0);
    gtk_box_pack_start (GTK_BOX(hbox), vbox1, TRUE, FALSE, 0);

    /* ----------------------------------- */
    /* Top portion of screen (preferences) */
    /* ----------------------------------- */

    /* Make a temporary hbox */
    temp_hbox = gtk_hbox_new (FALSE, 0);

    /* Sync when radio buttons */
    plucker_get_pref (SYNC_WHEN, &ivalue, NULL);

    label = gtk_label_new ("Run distiller:");
    gtk_box_pack_start (GTK_BOX(temp_hbox), label, FALSE, FALSE, 5);

    button = gtk_radio_button_new_with_label (NULL, "Every Sync");
    gtk_signal_connect (GTK_OBJECT (button), "toggled",
                        GTK_SIGNAL_FUNC (cb_toggle_button),
                        GINT_TO_POINTER (EVERY_SYNC_BUTTON));
    gtk_box_pack_start (GTK_BOX (temp_hbox), button, TRUE, FALSE, 0);
    if (ivalue == EVERY_SYNC) {
        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
    }

    button = gtk_radio_button_new_with_label(gtk_radio_button_group (GTK_RADIO_BUTTON (button)),
                                             "Hourly");
    gtk_signal_connect (GTK_OBJECT (button), "toggled",
                        GTK_SIGNAL_FUNC (cb_toggle_button),
                        GINT_TO_POINTER (HOURLY_BUTTON));
    gtk_box_pack_start (GTK_BOX (temp_hbox), button, TRUE, FALSE, 0);
    if (ivalue == HOURLY) {
        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
    }

    button = gtk_radio_button_new_with_label(gtk_radio_button_group (GTK_RADIO_BUTTON (button)),
                                             "Morning & Afternoon");
    gtk_signal_connect (GTK_OBJECT (button), "toggled",
                        GTK_SIGNAL_FUNC (cb_toggle_button),
                        GINT_TO_POINTER (MORNING_AND_AFTERNOON_BUTTON));
    gtk_box_pack_start (GTK_BOX (temp_hbox), button, TRUE, FALSE, 0);
    if (ivalue == MORNING_AND_AFTERNOON) {
        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
    }

    button = gtk_radio_button_new_with_label(gtk_radio_button_group (GTK_RADIO_BUTTON (button)),
                                             "Daily");
    gtk_signal_connect (GTK_OBJECT (button), "toggled",
                        GTK_SIGNAL_FUNC (cb_toggle_button),
                        GINT_TO_POINTER (DAILY_BUTTON));
    gtk_box_pack_start (GTK_BOX (temp_hbox), button, TRUE, FALSE, 0);
    if (ivalue == DAILY) {
        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
    }

    button = gtk_radio_button_new_with_label(gtk_radio_button_group (GTK_RADIO_BUTTON (button)),
                                             "Manual");
    gtk_signal_connect (GTK_OBJECT (button), "toggled",
                        GTK_SIGNAL_FUNC (cb_toggle_button),
                        GINT_TO_POINTER (MANUAL_BUTTON));
    gtk_box_pack_start (GTK_BOX (temp_hbox), button, TRUE, FALSE, 0);
    if (ivalue == MANUAL) {
        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
    }


    gtk_box_pack_start (GTK_BOX(vbox1), temp_hbox, FALSE, FALSE, 5);
    gtk_box_pack_start (GTK_BOX(vbox1), gtk_hseparator_new(), FALSE, FALSE, 0);

    /* distiller command */
    temp_hbox = gtk_hbox_new (FALSE, 0);

    label = gtk_label_new ("Distiller command:");
    gtk_box_pack_start (GTK_BOX(temp_hbox), label, FALSE, FALSE, 5);

    distiller_cmd_entry = gtk_entry_new();
    plucker_get_pref (DISTILLER_CMD, NULL, &svalue);
    if (svalue) {
        gtk_entry_set_text (GTK_ENTRY(distiller_cmd_entry), svalue);
    }

    gtk_box_pack_start (GTK_BOX(temp_hbox), distiller_cmd_entry, TRUE, TRUE, 5);

    gtk_box_pack_start (GTK_BOX(vbox1), temp_hbox, FALSE, FALSE, 5);

    /* run in terminal button */
    temp_hbox = gtk_hbox_new (FALSE, 0);

    button = gtk_check_button_new_with_label ("Run in Terminal");
    plucker_get_pref (USE_TERM, &ivalue, NULL);
    gtk_signal_connect (GTK_OBJECT (button), "toggled",
                        GTK_SIGNAL_FUNC (cb_use_term), NULL);
    gtk_box_pack_start (GTK_BOX(temp_hbox), button, FALSE, FALSE, 5);

    /* term command */
    terminal_label = gtk_label_new ("Terminal command:");
    gtk_box_pack_start (GTK_BOX(temp_hbox), terminal_label, FALSE, FALSE, 5);

    terminal_cmd_entry = gtk_entry_new();
    plucker_get_pref (TERM_CMD, NULL, &svalue);
    if (svalue) {
        gtk_entry_set_text (GTK_ENTRY(terminal_cmd_entry), svalue);
    }
    cb_use_term (button, NULL);

    gtk_box_pack_start (GTK_BOX(temp_hbox), terminal_cmd_entry, TRUE, TRUE, 5);

    gtk_box_pack_start (GTK_BOX(vbox1), temp_hbox, FALSE, FALSE, 5);

    /* install from dir */
    temp_hbox = gtk_hbox_new (FALSE, 0);

    label = gtk_label_new ("Install from:");
    gtk_box_pack_start (GTK_BOX(temp_hbox), label, FALSE, FALSE, 5);

    install_dir_entry = gtk_entry_new();
    plucker_get_pref (INSTALL_DIR, NULL, &svalue);
    if (svalue) {
        gtk_entry_set_text (GTK_ENTRY(install_dir_entry), svalue);
    }

    gtk_box_pack_start (GTK_BOX(temp_hbox), install_dir_entry, TRUE, TRUE, 5);

    gtk_box_pack_start (GTK_BOX(vbox1), temp_hbox, FALSE, FALSE, 5);

    /* run button */
    button = gtk_button_new_with_label ("Run Distiller");
    gtk_signal_connect (GTK_OBJECT(button), "clicked",
                        GTK_SIGNAL_FUNC(cb_run_distiller), NULL);
    gtk_box_pack_start (GTK_BOX(vbox1), button, FALSE, FALSE, 5);

    /* save button */
    gtk_box_pack_start (GTK_BOX(vbox1), gtk_hseparator_new(), FALSE, FALSE, 5);

    button = gtk_button_new_with_label ("Save Changes");
    gtk_signal_connect (GTK_OBJECT(button), "clicked",
                        GTK_SIGNAL_FUNC(cb_save), NULL);
    gtk_box_pack_start (GTK_BOX(vbox1), button, FALSE, FALSE, 5);


    gtk_widget_show_all (hbox);
    return 0;
}

int destroy_gui() {
    return 0;
}






/* ----------------------------------------------------------------------- */
/*                               Callbacks                                 */
/* ----------------------------------------------------------------------- */

static void cb_save (GtkWidget *widget, gpointer data) {
    gchar *str;
    int rval;

    str = gtk_entry_get_text(GTK_ENTRY(distiller_cmd_entry));
    plucker_set_pref (DISTILLER_CMD, 0, str);

    str = gtk_entry_get_text(GTK_ENTRY(terminal_cmd_entry));
    plucker_set_pref (TERM_CMD, 0, str);

    str = gtk_entry_get_text(GTK_ENTRY(install_dir_entry));
    plucker_set_pref (INSTALL_DIR, 0, str);

    jp_logf (JP_LOG_DEBUG, "saving prefs\n");
    rval = plucker_save_prefs();
    jp_logf (JP_LOG_DEBUG, "save returned [%d]\n", rval);
}


static void cb_toggle_button (GtkWidget *widget, gpointer data) {
    switch (GPOINTER_TO_INT (data)) {
        case EVERY_SYNC_BUTTON:
            jp_logf (JP_LOG_DEBUG, "every sync button\n");
            plucker_set_pref (SYNC_WHEN, EVERY_SYNC, NULL);
            break;

        case HOURLY_BUTTON:
            jp_logf (JP_LOG_DEBUG, "hourly button\n");
            plucker_set_pref (SYNC_WHEN, HOURLY, NULL);
            break;

        case MORNING_AND_AFTERNOON_BUTTON:
            jp_logf (JP_LOG_DEBUG, "morning & afternoon button\n");
            plucker_set_pref (SYNC_WHEN, MORNING_AND_AFTERNOON, NULL);
            break;

        case DAILY_BUTTON:
            jp_logf (JP_LOG_DEBUG, "daily button\n");
            plucker_set_pref (SYNC_WHEN, DAILY, NULL);
            break;

        case MANUAL_BUTTON:
            jp_logf (JP_LOG_DEBUG, "manual button\n");
            plucker_set_pref (SYNC_WHEN, MANUAL, NULL);
            break;

        default:
            jp_logf (JP_LOG_WARN, "Invalid button data: %d\n",
                         GPOINTER_TO_INT (data));
    }
}

static void cb_run_distiller (GtkWidget *widget, gpointer data) {
    const gchar *cmd = gtk_entry_get_text(GTK_ENTRY(distiller_cmd_entry));
    long ivalue;

    jp_logf (JP_LOG_DEBUG, "distiller command: [%s]\n", cmd);

    plucker_get_pref (USE_TERM, &ivalue, NULL);
    if (ivalue) {
        const gchar *terminal_cmd = gtk_entry_get_text(GTK_ENTRY(terminal_cmd_entry));
        jp_logf (JP_LOG_DEBUG, "terminal command: [%s]\n", terminal_cmd);
        run_distiller_in_term (terminal_cmd, cmd, FALSE);
    }
    else {
        run_distiller (cmd, FALSE);
    }
}

static void cb_use_term (GtkWidget *widget, gpointer data) {
    gboolean enabled = GTK_TOGGLE_BUTTON(widget)->active;

    plucker_set_pref (USE_TERM, enabled, NULL);
    gtk_widget_set_sensitive (terminal_label, enabled);
    gtk_widget_set_sensitive (terminal_cmd_entry, enabled);
}

