/* pprefs.c
 *
 * Copyright (C) 2003 by Jason Day
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "config.h"

#include <stdio.h>

#include "libplugin.h"
#include "pprefs.h"
#include "plucker.h"

static const char RCSID[] = "$Id: pprefs.c,v 1.4 2003/06/03 17:41:37 jday Exp $";


#define NUM_PREFS 6
static prefType plucker_prefs[NUM_PREFS] = {
    {"sync_when",         INTTYPE,  INTTYPE,  EVERY_SYNC, NULL,         0},
    {"distiller_command", CHARTYPE, CHARTYPE, 0,          NULL,         0},
    {"use_term",          INTTYPE,  INTTYPE,  0,          NULL,         0},
    {"term_command",      CHARTYPE, CHARTYPE, 0,          "xterm",      0},
    {"last_sync",         CHARTYPE, CHARTYPE, 0,          NULL,         0},
    {"install_dir",       CHARTYPE, CHARTYPE, 0,          NULL,         0},
};


void plucker_prefs_init() {
    jp_pref_init (plucker_prefs, NUM_PREFS);
}

int plucker_get_pref (int which, long *n, const char **string) {
    if (which > NUM_PREFS) {
        return -1;
    }

    return jp_get_pref (plucker_prefs, which, n, string);
}

int plucker_set_pref (int which, long n, const char *string) {
    int rval = 0;

    if (which > NUM_PREFS) {
        return -1;
    }

    jp_logf (JP_LOG_DEBUG, "which is [%d] n is [%d]\n", which, n);
    rval = jp_set_pref (plucker_prefs, which, n, string);
    jp_logf (JP_LOG_DEBUG, "name is %s value = %d\n", plucker_prefs[which].name, plucker_prefs[which].ivalue);

    return rval;
}

int plucker_load_prefs() {
    return jp_pref_read_rc_file (PREFS_FILE, plucker_prefs, NUM_PREFS);
}

int plucker_save_prefs() {
    jp_logf (JP_LOG_DEBUG, "calling write with filename [%s] num [%d]\n", PREFS_FILE, NUM_PREFS);
    return jp_pref_write_rc_file (PREFS_FILE, plucker_prefs, NUM_PREFS);
}

void plucker_free_prefs() {
    jp_free_prefs (plucker_prefs, NUM_PREFS);
}
